var servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1ExtendedUser =
[
    [ "com::sun::star::text::TextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1ExtendedUser.html#ac5c12dd117b70431d72eeb6ab9507fd2", null ],
    [ "Content", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1ExtendedUser.html#a6d1fb265b40351e94f79e0f749e5daf9", null ],
    [ "CurrentPresentation", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1ExtendedUser.html#a632a1788f5e2e009b3809bbb266e39a0", null ],
    [ "IsFixed", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1ExtendedUser.html#a57c3add6784f715a9bed21c3318f41ba", null ],
    [ "UserDataType", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1ExtendedUser.html#ae9582be4fd2447f41445081b96c5e418", null ]
];